# smaksimovich

Do you ever need some function that you remember writing a long time ago, but forgot where that code is, or are too lazy to go and find it? This is my solution to this problem. 

This package hosts random utility functions that I have found myself needing multiple times. Instead of rewriting them, I made a package to easily access them, and placing it online so I can access it on different machines.

I don't expect anyone to use this package, but myself.